@@ -36,10 +36,8 @@ class CfnScalingPlan(
 ):
     """A CloudFormation ``AWS::AutoScalingPlans::ScalingPlan``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::AutoScalingPlans::ScalingPlan
+    :cloudformationResource: AWS::AutoScalingPlans::ScalingPlan
     """
 
     def __init__(
@@ -47,8 +45,8 @@ class CfnScalingPlan(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        application_source: typing.Union["ApplicationSourceProperty", aws_cdk.core.IResolvable],
-        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ScalingInstructionProperty"]]],
+        application_source: typing.Union["CfnScalingPlan.ApplicationSourceProperty", aws_cdk.core.IResolvable],
+        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]],
     ) -> None:
         """Create a new ``AWS::AutoScalingPlans::ScalingPlan``.
 
@@ -66,11 +64,10 @@ class CfnScalingPlan(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -95,8 +92,7 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="attrScalingPlanName")
     def attr_scaling_plan_name(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ScalingPlanName
+        :cloudformationAttribute: ScalingPlanName
         """
         return jsii.get(self, "attrScalingPlanName")
 
@@ -104,8 +100,7 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="attrScalingPlanVersion")
     def attr_scaling_plan_version(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ScalingPlanVersion
+        :cloudformationAttribute: ScalingPlanVersion
         """
         return jsii.get(self, "attrScalingPlanVersion")
 
@@ -118,10 +113,9 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="applicationSource")
     def application_source(
         self,
-    ) -> typing.Union["ApplicationSourceProperty", aws_cdk.core.IResolvable]:
+    ) -> typing.Union["CfnScalingPlan.ApplicationSourceProperty", aws_cdk.core.IResolvable]:
         """``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-applicationsource
         """
         return jsii.get(self, "applicationSource")
@@ -129,7 +123,7 @@ class CfnScalingPlan(
     @application_source.setter # type: ignore
     def application_source(
         self,
-        value: typing.Union["ApplicationSourceProperty", aws_cdk.core.IResolvable],
+        value: typing.Union["CfnScalingPlan.ApplicationSourceProperty", aws_cdk.core.IResolvable],
     ) -> None:
         jsii.set(self, "applicationSource", value)
 
@@ -137,10 +131,9 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="scalingInstructions")
     def scaling_instructions(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ScalingInstructionProperty"]]]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]]:
         """``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-scalinginstructions
         """
         return jsii.get(self, "scalingInstructions")
@@ -148,7 +141,7 @@ class CfnScalingPlan(
     @scaling_instructions.setter # type: ignore
     def scaling_instructions(
         self,
-        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ScalingInstructionProperty"]]],
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]],
     ) -> None:
         jsii.set(self, "scalingInstructions", value)
 
@@ -171,7 +164,6 @@ class CfnScalingPlan(
             :param cloud_formation_stack_arn: ``CfnScalingPlan.ApplicationSourceProperty.CloudFormationStackARN``.
             :param tag_filters: ``CfnScalingPlan.ApplicationSourceProperty.TagFilters``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-applicationsource.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -184,7 +176,6 @@ class CfnScalingPlan(
         def cloud_formation_stack_arn(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ApplicationSourceProperty.CloudFormationStackARN``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-applicationsource.html#cfn-autoscalingplans-scalingplan-applicationsource-cloudformationstackarn
             """
             result = self._values.get("cloud_formation_stack_arn")
@@ -196,7 +187,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.TagFilterProperty"]]]]:
             """``CfnScalingPlan.ApplicationSourceProperty.TagFilters``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-applicationsource.html#cfn-autoscalingplans-scalingplan-applicationsource-tagfilters
             """
             result = self._values.get("tag_filters")
@@ -241,7 +231,6 @@ class CfnScalingPlan(
             :param dimensions: ``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Dimensions``.
             :param unit: ``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -258,7 +247,6 @@ class CfnScalingPlan(
         def metric_name(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.MetricName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-metricname
             """
             result = self._values.get("metric_name")
@@ -269,7 +257,6 @@ class CfnScalingPlan(
         def namespace(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Namespace``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-namespace
             """
             result = self._values.get("namespace")
@@ -280,7 +267,6 @@ class CfnScalingPlan(
         def statistic(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Statistic``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-statistic
             """
             result = self._values.get("statistic")
@@ -293,7 +279,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.MetricDimensionProperty"]]]]:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Dimensions``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-dimensions
             """
             result = self._values.get("dimensions")
@@ -303,7 +288,6 @@ class CfnScalingPlan(
         def unit(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedloadmetricspecification-unit
             """
             result = self._values.get("unit")
@@ -348,7 +332,6 @@ class CfnScalingPlan(
             :param dimensions: ``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Dimensions``.
             :param unit: ``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -365,7 +348,6 @@ class CfnScalingPlan(
         def metric_name(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.MetricName``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-metricname
             """
             result = self._values.get("metric_name")
@@ -376,7 +358,6 @@ class CfnScalingPlan(
         def namespace(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Namespace``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-namespace
             """
             result = self._values.get("namespace")
@@ -387,7 +368,6 @@ class CfnScalingPlan(
         def statistic(self) -> builtins.str:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Statistic``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-statistic
             """
             result = self._values.get("statistic")
@@ -400,7 +380,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.MetricDimensionProperty"]]]]:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Dimensions``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-dimensions
             """
             result = self._values.get("dimensions")
@@ -410,7 +389,6 @@ class CfnScalingPlan(
         def unit(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Unit``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-customizedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-customizedscalingmetricspecification-unit
             """
             result = self._values.get("unit")
@@ -438,7 +416,6 @@ class CfnScalingPlan(
             :param name: ``CfnScalingPlan.MetricDimensionProperty.Name``.
             :param value: ``CfnScalingPlan.MetricDimensionProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-metricdimension.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -450,7 +427,6 @@ class CfnScalingPlan(
         def name(self) -> builtins.str:
             """``CfnScalingPlan.MetricDimensionProperty.Name``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-metricdimension.html#cfn-autoscalingplans-scalingplan-metricdimension-name
             """
             result = self._values.get("name")
@@ -461,7 +437,6 @@ class CfnScalingPlan(
         def value(self) -> builtins.str:
             """``CfnScalingPlan.MetricDimensionProperty.Value``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-metricdimension.html#cfn-autoscalingplans-scalingplan-metricdimension-value
             """
             result = self._values.get("value")
@@ -498,7 +473,6 @@ class CfnScalingPlan(
             :param predefined_load_metric_type: ``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.PredefinedLoadMetricType``.
             :param resource_label: ``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedloadmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -511,7 +485,6 @@ class CfnScalingPlan(
         def predefined_load_metric_type(self) -> builtins.str:
             """``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.PredefinedLoadMetricType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedloadmetricspecification-predefinedloadmetrictype
             """
             result = self._values.get("predefined_load_metric_type")
@@ -522,7 +495,6 @@ class CfnScalingPlan(
         def resource_label(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.PredefinedLoadMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedloadmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedloadmetricspecification-resourcelabel
             """
             result = self._values.get("resource_label")
@@ -558,7 +530,6 @@ class CfnScalingPlan(
             :param predefined_scaling_metric_type: ``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.PredefinedScalingMetricType``.
             :param resource_label: ``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedscalingmetricspecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -571,7 +542,6 @@ class CfnScalingPlan(
         def predefined_scaling_metric_type(self) -> builtins.str:
             """``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.PredefinedScalingMetricType``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedscalingmetricspecification-predefinedscalingmetrictype
             """
             result = self._values.get("predefined_scaling_metric_type")
@@ -582,7 +552,6 @@ class CfnScalingPlan(
         def resource_label(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.PredefinedScalingMetricSpecificationProperty.ResourceLabel``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-predefinedscalingmetricspecification.html#cfn-autoscalingplans-scalingplan-predefinedscalingmetricspecification-resourcelabel
             """
             result = self._values.get("resource_label")
@@ -654,7 +623,6 @@ class CfnScalingPlan(
             :param scaling_policy_update_behavior: ``CfnScalingPlan.ScalingInstructionProperty.ScalingPolicyUpdateBehavior``.
             :param scheduled_action_buffer_time: ``CfnScalingPlan.ScalingInstructionProperty.ScheduledActionBufferTime``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -686,7 +654,6 @@ class CfnScalingPlan(
         def max_capacity(self) -> jsii.Number:
             """``CfnScalingPlan.ScalingInstructionProperty.MaxCapacity``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-maxcapacity
             """
             result = self._values.get("max_capacity")
@@ -697,7 +664,6 @@ class CfnScalingPlan(
         def min_capacity(self) -> jsii.Number:
             """``CfnScalingPlan.ScalingInstructionProperty.MinCapacity``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-mincapacity
             """
             result = self._values.get("min_capacity")
@@ -708,7 +674,6 @@ class CfnScalingPlan(
         def resource_id(self) -> builtins.str:
             """``CfnScalingPlan.ScalingInstructionProperty.ResourceId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-resourceid
             """
             result = self._values.get("resource_id")
@@ -719,7 +684,6 @@ class CfnScalingPlan(
         def scalable_dimension(self) -> builtins.str:
             """``CfnScalingPlan.ScalingInstructionProperty.ScalableDimension``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-scalabledimension
             """
             result = self._values.get("scalable_dimension")
@@ -730,7 +694,6 @@ class CfnScalingPlan(
         def service_namespace(self) -> builtins.str:
             """``CfnScalingPlan.ScalingInstructionProperty.ServiceNamespace``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-servicenamespace
             """
             result = self._values.get("service_namespace")
@@ -743,7 +706,6 @@ class CfnScalingPlan(
         ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.TargetTrackingConfigurationProperty"]]]:
             """``CfnScalingPlan.ScalingInstructionProperty.TargetTrackingConfigurations``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-targettrackingconfigurations
             """
             result = self._values.get("target_tracking_configurations")
@@ -756,7 +718,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.CustomizedLoadMetricSpecificationProperty"]]:
             """``CfnScalingPlan.ScalingInstructionProperty.CustomizedLoadMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-customizedloadmetricspecification
             """
             result = self._values.get("customized_load_metric_specification")
@@ -768,7 +729,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnScalingPlan.ScalingInstructionProperty.DisableDynamicScaling``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-disabledynamicscaling
             """
             result = self._values.get("disable_dynamic_scaling")
@@ -780,7 +740,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.PredefinedLoadMetricSpecificationProperty"]]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredefinedLoadMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predefinedloadmetricspecification
             """
             result = self._values.get("predefined_load_metric_specification")
@@ -792,7 +751,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredictiveScalingMaxCapacityBehavior``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predictivescalingmaxcapacitybehavior
             """
             result = self._values.get("predictive_scaling_max_capacity_behavior")
@@ -804,7 +762,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredictiveScalingMaxCapacityBuffer``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predictivescalingmaxcapacitybuffer
             """
             result = self._values.get("predictive_scaling_max_capacity_buffer")
@@ -814,7 +771,6 @@ class CfnScalingPlan(
         def predictive_scaling_mode(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredictiveScalingMode``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-predictivescalingmode
             """
             result = self._values.get("predictive_scaling_mode")
@@ -824,7 +780,6 @@ class CfnScalingPlan(
         def scaling_policy_update_behavior(self) -> typing.Optional[builtins.str]:
             """``CfnScalingPlan.ScalingInstructionProperty.ScalingPolicyUpdateBehavior``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-scalingpolicyupdatebehavior
             """
             result = self._values.get("scaling_policy_update_behavior")
@@ -834,7 +789,6 @@ class CfnScalingPlan(
         def scheduled_action_buffer_time(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.ScalingInstructionProperty.ScheduledActionBufferTime``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-scalinginstruction.html#cfn-autoscalingplans-scalingplan-scalinginstruction-scheduledactionbuffertime
             """
             result = self._values.get("scheduled_action_buffer_time")
@@ -867,7 +821,6 @@ class CfnScalingPlan(
             :param key: ``CfnScalingPlan.TagFilterProperty.Key``.
             :param values: ``CfnScalingPlan.TagFilterProperty.Values``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-tagfilter.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -880,7 +833,6 @@ class CfnScalingPlan(
         def key(self) -> builtins.str:
             """``CfnScalingPlan.TagFilterProperty.Key``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-tagfilter.html#cfn-autoscalingplans-scalingplan-tagfilter-key
             """
             result = self._values.get("key")
@@ -891,7 +843,6 @@ class CfnScalingPlan(
         def values(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnScalingPlan.TagFilterProperty.Values``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-tagfilter.html#cfn-autoscalingplans-scalingplan-tagfilter-values
             """
             result = self._values.get("values")
@@ -942,7 +893,6 @@ class CfnScalingPlan(
             :param scale_in_cooldown: ``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleInCooldown``.
             :param scale_out_cooldown: ``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleOutCooldown``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -965,7 +915,6 @@ class CfnScalingPlan(
         def target_value(self) -> jsii.Number:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.TargetValue``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-targetvalue
             """
             result = self._values.get("target_value")
@@ -978,7 +927,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.CustomizedScalingMetricSpecificationProperty"]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.CustomizedScalingMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-customizedscalingmetricspecification
             """
             result = self._values.get("customized_scaling_metric_specification")
@@ -990,7 +938,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.DisableScaleIn``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-disablescalein
             """
             result = self._values.get("disable_scale_in")
@@ -1000,7 +947,6 @@ class CfnScalingPlan(
         def estimated_instance_warmup(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.EstimatedInstanceWarmup``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-estimatedinstancewarmup
             """
             result = self._values.get("estimated_instance_warmup")
@@ -1012,7 +958,6 @@ class CfnScalingPlan(
         ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.PredefinedScalingMetricSpecificationProperty"]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.PredefinedScalingMetricSpecification``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-predefinedscalingmetricspecification
             """
             result = self._values.get("predefined_scaling_metric_specification")
@@ -1022,7 +967,6 @@ class CfnScalingPlan(
         def scale_in_cooldown(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleInCooldown``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-scaleincooldown
             """
             result = self._values.get("scale_in_cooldown")
@@ -1032,7 +976,6 @@ class CfnScalingPlan(
         def scale_out_cooldown(self) -> typing.Optional[jsii.Number]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.ScaleOutCooldown``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscalingplans-scalingplan-targettrackingconfiguration.html#cfn-autoscalingplans-scalingplan-targettrackingconfiguration-scaleoutcooldown
             """
             result = self._values.get("scale_out_cooldown")
@@ -1062,15 +1005,14 @@ class CfnScalingPlanProps:
     def __init__(
         self,
         *,
-        application_source: typing.Union["CfnScalingPlan.ApplicationSourceProperty", aws_cdk.core.IResolvable],
-        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]],
+        application_source: typing.Union[CfnScalingPlan.ApplicationSourceProperty, aws_cdk.core.IResolvable],
+        scaling_instructions: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnScalingPlan.ScalingInstructionProperty]]],
     ) -> None:
         """Properties for defining a ``AWS::AutoScalingPlans::ScalingPlan``.
 
         :param application_source: ``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
         :param scaling_instructions: ``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -1081,10 +1023,9 @@ class CfnScalingPlanProps:
     @builtins.property
     def application_source(
         self,
-    ) -> typing.Union["CfnScalingPlan.ApplicationSourceProperty", aws_cdk.core.IResolvable]:
+    ) -> typing.Union[CfnScalingPlan.ApplicationSourceProperty, aws_cdk.core.IResolvable]:
         """``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-applicationsource
         """
         result = self._values.get("application_source")
@@ -1094,10 +1035,9 @@ class CfnScalingPlanProps:
     @builtins.property
     def scaling_instructions(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnScalingPlan.ScalingInstructionProperty"]]]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnScalingPlan.ScalingInstructionProperty]]]:
         """``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-scalinginstructions
         """
         result = self._values.get("scaling_instructions")
